pub struct MeasuredValuesSen69c {
pub pm_1_0: Option<MicrogramsPerCubicMeter>,
pub pm_2_5: Option<MicrogramsPerCubicMeter>,
pub pm_4_0: Option<MicrogramsPerCubicMeter>,
pub pm_10_0: Option<MicrogramsPerCubicMeter>,
pub ambient_humidity: Option<Percent>,
pub ambient_temperature: Option<DegCelsius>,
pub voc_index: Option<Index>,
pub nox_index: Option<Index>,
pub hcho: Option<Ppb>,
pub co2: Option<Ppm>,
}Expand description
Measured values returned by a SEN69C (PM, RH/T, VOC, NOx, formaldehyde and CO₂).
A field is None when that value is unavailable (for example, when no
measurement has been running for at least one second).
Fields
pm_1_0: Option<MicrogramsPerCubicMeter>Mass Concentration PM1.0
pm_2_5: Option<MicrogramsPerCubicMeter>Mass Concentration PM2.5
pm_4_0: Option<MicrogramsPerCubicMeter>Mass Concentration PM4.0
pm_10_0: Option<MicrogramsPerCubicMeter>Mass Concentration PM10.0
ambient_humidity: Option<Percent>Ambient Humidity
ambient_temperature: Option<DegCelsius>Ambient Temperature
voc_index: Option<Index>VOC Index
nox_index: Option<Index>NOx Index
hcho: Option<Ppb>Formaldehyde concentration
co2: Option<Ppm>CO2 concentration